Oktavia for Python
=======================

This is a search engine based on FM-index.
This is a Python port of original JSX version.

Now it is an alpha version. I am adding Python 3.4 support and more detail document.

Testing
~~~~~~~

.. code-block:: bash

   $ nosetests tests

Link
---------

* http://oktavia.info
